@@ -23,8 +23,6 @@ describe 'keystone' do
       'admin_password'                     => 'special_password',
       'package_ensure'                     => 'present',
       'client_package_ensure'              => 'present',
-      'public_bind_host'                   => '0.0.0.0',
-      'public_port'                        => '5000',
       'catalog_type'                       => 'sql',
       'catalog_driver'                     => false,
       'token_provider'                     => 'fernet',
@@ -207,9 +205,12 @@ describe 'keystone' do
        'public_bind_host',
        'public_port',
       ].each do |config|
-        is_expected.to contain_keystone_config("eventlet_server/#{config}").with_value(param_hash[config])
+        if param_hash[config]
+          is_expected.to contain_keystone_config("eventlet_server/#{config}").with_value(param_hash[config])
+        else
+          is_expected.to_not contain_keystone_config("eventlet_server/#{config}")
+        end
       end
-
     end
 
     it 'should ensure rabbit_ha_queues' do
